<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul" 
	exclude-result-prefixes="sm sc">
	
<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	
<xsl:include href="bsco:sm/wspDef/mainviewIdInView.xul.xsl"/>

<xsl:variable name="vAuthoring" select="sm:authoring"/>
<xsl:variable name="vIsReadOnly" select="resultatAgent('@@/isReadOnly', codeAgent('//'))='true'"/>
	
<xsl:template match="sm:blocksTab[@display!='hidden'][not(@usedIn='nonBinaryClasses')]" mode="mainview">
<xsl:variable name="vContent"><xsl:apply-templates mode="mainview"/></xsl:variable>
<xsl:if test="boolean($vContent)">
<sctab label="{returnFirst(@label, @name)}" description="{@name}" 
				code="bk_{count(preceding-sibling::sm:blocksTab)}"
				collapsed="{@display='extra'}">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="tabStyle"/>
<xsl:call-template name="idInView"/>
<xsl:copy-of select="$vContent"/>
</sctab>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:generatorsBlock" mode="mainview">
<generatorBlock titleblock="{@name}">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
<xsl:apply-templates mode="mainview"/>
</generatorBlock>
</xsl:template>
<xsl:template match="sm:genBox" mode="mainview">
<xsl:variable name="vGen" select="agent(concat('@', getIdFromPath(sm:generator/@sc:refUri)))"/>
<xsl:if test="$vGen">
<genBox cdGen="{resultatAgent($vGen/codeGenerator)}" actionsLists="gen:{resultatAgent($vGen/codeGenerator)}:actions" title="{returnFirst(@name, resultatAgent($vGen/nameGenerator))}" defaultIcon="{resultatAgent($vGen/iconGenerator)}">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="idInView"/>
<xsl:if test="not(resultatAgent('/@@/isIncludeGenerator', resultatAgent($vGen/codeGenerator)))">
<message status="warning" msg="Ce générateur n'a pas été compilé et est donc inutilisable" style="-moz-binding: url(chrome://scenariCore/content/widgets/message/message.xbl.xml#message);"/>
</xsl:if>
<xsl:apply-templates mode="mainview"/>
</genBox>
</xsl:if>
</xsl:template>
<xsl:template match="sm:deployment" mode="mainview">
<xsl:param name="pAncestorCdGen"/>
<xsl:variable name="vGenDeploy" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:if test="$vGenDeploy">
<subGenBox 	image="{resultatAgent($vGenDeploy/iconGenerator)}" 
						title="{resultatAgent($vGenDeploy/nameGenerator)}..."
						style="-moz-binding: url('{resultatDialogue(dialog($vGenDeploy/editionSheets), 'act:')}#subGen')">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="idInView"/>
<xsl:if test="not(resultatAgent('/@@/isIncludeGenerator', resultatAgent($vGenDeploy/codeGenerator)))">
<message status="warning" msg="Le sous-générateur '{resultatAgent($vGenDeploy/nameGenerator)}' n'a pas été compilé et est donc inutilisable" style="-moz-binding: url(chrome://scenariCore/content/widgets/message/message.xbl.xml#message);"/>
</xsl:if>
</subGenBox>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:technicalInfoBlock[not(@usedIn='nonBinaryClasses')]" mode="mainview">
<infotechblock titleblock="{@name}">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
</infotechblock>
</xsl:template>
	
<xsl:template match="sm:formEditorTab[@display!='hidden'][not(@usedIn='nonBinaryClasses')]" mode="mainview">
<xsl:if test="resultatAgent('//withProps')='true'">
<xsl:variable name="vEditorModel" select="resultatAgent(concat('//form', @formEditorKey, '.xed.xml'), 'act:')"/>
<xsl:if test="$vEditorModel">
<sctabxmleditor label="{returnFirst(@label, @name)}" description="{@name}" code="formEdit"
					indent="true"
					model="{$vEditorModel}"
					urires="/meta.xml"
					collapsed="{@display='extra'}">
<xsl:if test="$vIsReadOnly"><xsl:attribute name="readonly">true</xsl:attribute></xsl:if>
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="tabStyle"/>
<xsl:call-template name="idInView"/>
</sctabxmleditor>
<box/>
</xsl:if>
</xsl:if>
</xsl:template>
	
<xsl:template name="displayMode">
<xsl:choose>
<xsl:when test="@displayMode='openedByDefault'">
<xsl:attribute name="openblock">true</xsl:attribute>
</xsl:when>
<xsl:when test="@displayMode='closedByDefault'">
<xsl:attribute name="openblock">false</xsl:attribute>
</xsl:when>
<xsl:when test="@displayMode='lockedOpen'">
<xsl:attribute name="alwaysOpen">true</xsl:attribute>
</xsl:when>
</xsl:choose>
</xsl:template>
	
<xsl:template match="*" mode="mainview"/>
<xsl:template match="text()|@*" mode="mainview"/>

</xsl:stylesheet>
