<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul" 
	exclude-result-prefixes="sm sc">
	
<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	
<xsl:include href="bsco:sm/wspDef/mainviewIdInView.xul.xsl"/>

<xsl:variable name="vAuthoring" select="sm:authoring"/>
	
<xsl:template match="sm:blocksTab[@display!='hidden'][not(@usedIn='binaryClasses')]" mode="mainview">
<xsl:variable name="vContent"><xsl:apply-templates mode="mainview"/></xsl:variable>
<xsl:if test="boolean($vContent)">
<sctab label="{returnFirst(@label, @name)}" description="{@name}" 
				icon="chrome://scenariWsp/content/widgets/sctab/icon/home.png"
				code="bk_{count(preceding-sibling::sm:blocksTab)}"
				collapsed="{@display='extra'}">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="idInView"/>
<xsl:call-template name="tabStyle"/>
<xsl:copy-of select="$vContent"/>
</sctab>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:previewBlock" mode="mainview">
<xsl:choose>
<xsl:when test="resultatAgent('//preview/type')='free'">
<xsl:variable name="scPreviewResUrl" select="concat('chrome://', resultatAgent('/@@/chromeCode'), '/content/', resultatAgent('//codeModel'), '/preview')"/>
<xsl:variable name="scModelUrl" select="concat('chrome://', resultatAgent('/@@/chromeCode'), '/content')"/>
<blockhtml titleblock="{@name}" xsloncontent="{resultatAgent('//preview', '')}" xslparams="{{scPreviewResUrl: '{$scPreviewResUrl}', scModelUrl: '{$scModelUrl}'}}">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
</blockhtml>
</xsl:when>
<xsl:otherwise>
			    
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template match="sm:displayingBlock[sm:interactiveGenerator/@sc:refUri]" mode="mainview">
<blockItemDynGen titleblock="{@name}" cdGen="{resultatAgent(concat('@', getIdFromPath(sm:interactiveGenerator/@sc:refUri), '/codeGenerator'))}" logsrc="true">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
</blockItemDynGen>
</xsl:template>
<xsl:template match="sm:generatorsBlock" mode="mainview">
<generatorBlock titleblock="{@name}">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
<xsl:apply-templates mode="mainview"/>
</generatorBlock>
</xsl:template>
<xsl:template match="sm:genBox" mode="mainview">
<xsl:variable name="vGen" select="agent(concat('@', getIdFromPath(sm:generator/@sc:refUri)))"/>
<xsl:if test="$vGen">
<genBox cdGen="{resultatAgent($vGen/codeGenerator)}" actionsLists="gen:{resultatAgent($vGen/codeGenerator)}:actions" title="{returnFirst(@name, resultatAgent($vGen/nameGenerator))}" defaultIcon="{resultatAgent($vGen/iconGenerator)}">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="idInView"/>
<xsl:if test="not(resultatAgent('/@@/isIncludeGenerator', resultatAgent($vGen/codeGenerator)))">
<message status="warning" msg="Ce générateur n'a pas été compilé et est donc inutilisable" style="-moz-binding: url(chrome://scenariCore/content/widgets/message/message.xbl.xml#message);"/>
</xsl:if>
<xsl:apply-templates mode="mainview"/>
</genBox>
</xsl:if>
</xsl:template>
<xsl:template match="sm:deployment" mode="mainview">
<xsl:param name="pAncestorCdGen"/>
<xsl:variable name="vGenDeploy" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:if test="$vGenDeploy">
<subGenBox 	image="{resultatAgent($vGenDeploy/iconGenerator)}" 
						title="{resultatAgent($vGenDeploy/nameGenerator)}..."
						style="-moz-binding: url('{resultatDialogue(dialog($vGenDeploy/editionSheets), 'act:')}#subGen')">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="idInView"/>
<xsl:if test="not(resultatAgent('/@@/isIncludeGenerator', resultatAgent($vGenDeploy/codeGenerator)))">
<message status="warning" msg="Le sous-générateur '{resultatAgent($vGenDeploy/nameGenerator)}' n'a pas été compilé et est donc inutilisable" style="-moz-binding: url(chrome://scenariCore/content/widgets/message/message.xbl.xml#message);"/>
</xsl:if>
</subGenBox>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:technicalInfoBlock[not(@usedIn='binaryClasses')]" mode="mainview">
<infotechblock titleblock="{@name}">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
</infotechblock>
</xsl:template>
<xsl:template match="sm:xmlViewBlock" mode="mainview">
<srcxmlblock titleblock="{@name}">
<xsl:call-template name="displayMode"/>
<xsl:call-template name="idInView"/>
</srcxmlblock>
</xsl:template>

<xsl:template match="sm:formEditorTab[@display!='hidden'][not(@usedIn='binaryClasses')]" mode="mainview">
<xsl:variable name="vEditorModel" select="resultatAgent(concat('//form', @formEditorKey, '.xed.xml'), 'act:')"/>
<xsl:if test="$vEditorModel">
<sctabxmleditor label="{returnFirst(@label, @name)}" description="{@name}" code="formEdit" 
				indent="{$vAuthoring/sm:formEditor[si(string(current()/@formEditorKey)!='', current()/@formEditorKey=@key, string(@key)='')]/@indentXml='true'}" 
				model="{$vEditorModel}"
				collapsed="{@display='extra'}">
<xsl:call-template name="tGetRightsMainviewAttributes">
<xsl:with-param name="pRightsTag" select="sm:perms"/>
</xsl:call-template>
<xsl:call-template name="idInView"/>
<xsl:call-template name="tabStyle"/>
<xsl:if test="resultatAgent('@@/isReadOnly', codeAgent('//'))='true'"><xsl:attribute name="readonly">true</xsl:attribute></xsl:if>
</sctabxmleditor>
</xsl:if>
</xsl:template>

<xsl:template match="sm:textEditorTab[@display!='hidden']" mode="mainview">
<sctabtexteditorxml label="{returnFirst(@label, @name)}" description="{@name}" 
			collapsed="{@display='extra'}">
<xsl:call-template name="idInView"/>
<xsl:call-template name="tabStyle"/>
</sctabtexteditorxml>
</xsl:template>
	
<xsl:template name="displayMode">
<xsl:choose>
<xsl:when test="@displayMode='openedByDefault'">
<xsl:attribute name="openblock">true</xsl:attribute>
</xsl:when>
<xsl:when test="@displayMode='closedByDefault'">
<xsl:attribute name="openblock">false</xsl:attribute>
</xsl:when>
<xsl:when test="@displayMode='lockedOpen'">
<xsl:attribute name="alwaysOpen">true</xsl:attribute>
</xsl:when>
</xsl:choose>
</xsl:template>
	
<xsl:template match="*" mode="mainview"/>
<xsl:template match="text()|@*" mode="mainview"/>
	
</xsl:stylesheet>
