<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:java="http://xml.apache.org/xslt/java" 
	version="1.0"
	exclude-result-prefixes="sm sc xalan">
	
<xsl:output method="xml" indent="no" omit-xml-declaration="yes"/>
	
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
	
<xsl:variable name="vStructureModel" select="computeNodeAgent(computeNodeAgent('//agentModel', 'source'))/sm:structure"/>

<xsl:template match="/*">
<view code="odContent"><xsl:apply-templates/></view>
<xsl:apply-templates mode="callSequenceCategory"/>
<xsl:apply-templates mode="callBlockCategory"/>
</xsl:template>
	
<xsl:template match="sm:inlineImgTag">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vDefModel" select="$vStructureModel/sm:inlineTags/sm:inlineImgTag[@role=current()/@role]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:if>
</xsl:template>	
		
<xsl:template match="sm:uLinkTag | sm:objectLeafTag">
<xsl:apply-templates select=".//*[name()='sm:subModelTitle' or name()='sm:callSubModel' or name()='sm:callSubModelMeta' or name()='sm:callModel']"/>
</xsl:template>
	
<xsl:template match="sm:subModelTitle">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vRootElmt" select="ancestor-or-self::*[name(..)='sm:content']"/>
<xsl:for-each select="$vStructureModel//*[name()=name($vRootElmt) and @role=$vRootElmt/@role]">
<xsl:for-each select=".//sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callSubModel">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vRootElmt" select="ancestor-or-self::*[name(..)='sm:content']"/>
<xsl:for-each select="$vStructureModel//*[name()=name($vRootElmt) and @role=$vRootElmt/@role]">
<xsl:for-each select=".//sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:current">
<call direction="current" model="{/sm:textOdTransf/sm:model/@sc:refUri}" axis="{@axis}" view="odContent"/>
</xsl:template>
	
<xsl:template match="sm:noteTag | sm:columnTag | sm:rowTag | sm:cellTag">
<call model="{/sm:textOdTransf/sm:model/@sc:refUri}" axis="{@axis}" view="odContent"/>
</xsl:template>
    
<xsl:template match="sm:callModel/sm:root">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="agentsLies(computeNodeAgent('//agentGenerator', 'listAgentRootAllowed'))">
<call model="{java:getSrcUri(srcFileAgent(.))}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:template>
<xsl:template match="sm:callModel/sm:agentPath">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callSubModelMeta">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vRootElmt" select="ancestor-or-self::*[name(..)='sm:content']"/>
<xsl:for-each select="$vStructureModel//*[name()=name($vRootElmt) and @role=$vRootElmt/@role]">
<xsl:for-each select=".//sm:allowedModel">
<xsl:variable name="vSubModelAgt" select="getIdFromPath(@sc:refUri)"/>
<call model="{$vSubModelAgt}" axis="" view="odContent"/>
<xsl:choose>
<xsl:when test="normalize-space(resultatAgent(concat('@', $vSubModelAgt,'/agentMeta')))!=''">
<xsl:variable name="vSubModelAgt_code" select="codeAgent(resultatAgent(concat('@', $vSubModelAgt,'/agentMeta')))"/>
<call model="{$vSubModelAgt_code}" axis="{$vAxis}" view="odContent"/>
</xsl:when>
<xsl:otherwise>
<call model="{$vSubModelAgt}" axis="" view="odContent" error="The model '{extractFileNameFromPath(@sc:refUri)}' has no meta"/>
</xsl:otherwise>
</xsl:choose>
</xsl:for-each>
</xsl:for-each>
</xsl:template>
	
	
<xsl:template match="sm:Widget">
		
<xsl:value-of select="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/viewsInfo'))" disable-output-escaping="yes"/>
<xsl:apply-templates/>
</xsl:template>
	
	
<xsl:template match="sm:captionTag | sm:caption" mode="callSequenceCategory">
<xsl:if test="@category">
<callSequenceCategory code="{@category}"/>
</xsl:if>
</xsl:template>
<xsl:template match="text()|@*" mode="callSequenceCategory"/>
	
	
<xsl:template match="sm:dataBlock" mode="callBlockCategory">
<callBlockCategory code="{@category}"/>
</xsl:template>
<xsl:template match="text()|@*" mode="callBlockCategory"/>
	
<xsl:template match="text()|@*"/>
	
</xsl:stylesheet>
