<?xml version="1.0" encoding="UTF-8"?>


<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:java="http://xml.apache.org/xslt/java" 
	version="1.0"
	exclude-result-prefixes="sm sc xalan java">
	
<xsl:output method="xml" indent="no" omit-xml-declaration="yes"/>
	
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
	
<xsl:variable name="vStructureModel" select="computeNodeAgent(computeNodeAgent('//agentModel', 'source'))/sm:structure"/>

<xsl:template match="/sm:compositionOdtTransf">
<view code="odContent">
<xsl:apply-templates/>
</view>
		
<xsl:variable name="vMetaModel" select="$vStructureModel/sm:meta/@sc:refUri"/>
<xsl:if test="$vMetaModel">
<view code="title"><call model="{$vMetaModel}" axis="" view="title"/></view>
</xsl:if>
<xsl:apply-templates mode="callSequenceCategory"/>
<xsl:apply-templates mode="callBlockCategory"/>
</xsl:template>
	
<xsl:template match="sm:callSubModel">
<xsl:variable name="vAxis">
<xsl:choose>
<xsl:when test="@axis='#inherited'"><xsl:value-of select="/*/sm:axis/@code"/></xsl:when>
<xsl:otherwise><xsl:value-of select="@axis"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:otherwise>odContent</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vCodes" select="si(@codes, @codes, ancestor::sm:for/@codes)"/>
<xsl:choose>
<xsl:when test="$vCodes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize($vCodes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:callSubModelMeta">
<xsl:variable name="vAxis">
<xsl:choose>
<xsl:when test="@axis='#inherited'"><xsl:value-of select="/*/sm:axis/@code"/></xsl:when>
<xsl:otherwise><xsl:value-of select="@axis"/></xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vCodes" select="si(@codes, @codes, ancestor::sm:for/@codes)"/>
<xsl:choose>
<xsl:when test="$vCodes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:allowedModel">
<xsl:variable name="vSubModelAgt" select="getIdFromPath(@sc:refUri)"/>
<call model="{@sc:refUri}" axis="" view="odContent"/>
<xsl:choose>
<xsl:when test="normalize-space(resultatAgent(concat('@', $vSubModelAgt,'/agentMeta')))!=''">
<xsl:variable name="vStructureSubModel" select="computeNodeAgent(concat('@', $vSubModelAgt,'/source'))/sm:structure"/>
<call model="{$vStructureSubModel/sm:meta/@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:when>
<xsl:otherwise>
<call model="{@sc:refUri}" axis="" view="odContent" error="The model '{extractFileNameFromPath(@sc:refUri)}' has no meta"/>
</xsl:otherwise>
</xsl:choose>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize($vCodes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<xsl:variable name="vSubModelAgt" select="getIdFromPath(@sc:refUri)"/>
<call model="{@sc:refUri}" axis="" view="odContent"/>
<xsl:choose>
<xsl:when test="normalize-space(resultatAgent(concat('@', $vSubModelAgt,'/agentMeta')))!=''">
<xsl:variable name="vStructureSubModel" select="computeNodeAgent(concat('@', $vSubModelAgt,'/source'))/sm:structure"/>
<call model="{$vStructureSubModel/sm:meta/@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:when>
<xsl:otherwise>
<call model="{@sc:refUri}" axis="" view="odContent" error="The model '{extractFileNameFromPath(@sc:refUri)}' has no meta"/>
</xsl:otherwise>
</xsl:choose>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:current">
<call direction="current" model="{/sm:compositionOdtTransf/sm:model/@sc:refUri}" axis="{@axis}" view="odContent"/>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:root">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="agentsLies(computeNodeAgent('//agentGenerator', 'listAgentRootAllowed'))">
<call model="{java:getSrcUri(srcFileAgent(.))}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:agentPath">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:lookForAscendants">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="odContent"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callPartMeta">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vCodes" select="si(@codes, @codes, ancestor::sm:for/@codes)"/>
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:otherwise>odContent</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:choose>
<xsl:when test="$vCodes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:meta|sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize($vCodes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:meta|$vDefModel/sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:callCompositionMeta">
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:otherwise>odContent</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<call model="{$vStructureModel/sm:meta/@sc:refUri}" axis="{@axis}" view="{$vView}"/>
</xsl:template>
	
<xsl:template match="sm:compositionTitle">
<call model="{$vStructureModel/sm:meta/@sc:refUri}" axis="{@axis}" view="title"/>
</xsl:template>
<xsl:template match="sm:partTitle">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vCodes" select="si(@codes, @codes, ancestor::sm:for/@codes)"/>
<xsl:choose>
<xsl:when test="$vCodes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:meta|sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize($vCodes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:meta|$vDefModel/sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template match="sm:subModelTitle">		
<xsl:variable name="vAxis" select="@axis"/>
<xsl:choose>
<xsl:when test="ancestor::sm:for/@codes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize(ancestor::sm:for/@codes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
	
<xsl:template match="sm:Widget">
		
<xsl:value-of select="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/viewsInfo'))" disable-output-escaping="yes"/>
<xsl:apply-templates/>
</xsl:template>
				
<xsl:template match="text()|@*"/>
	
	
<xsl:template match="sm:caption" mode="callSequenceCategory">
<callSequenceCategory code="{@category}"/>
</xsl:template>
<xsl:template match="text()|@*" mode="callSequenceCategory"/>
	
	
<xsl:template match="sm:dataBlock" mode="callBlockCategory">
<callBlockCategory code="{@category}"/>
</xsl:template>
<xsl:template match="text()|@*" mode="callBlockCategory"/>
	
</xsl:stylesheet>
