<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:sng="http://relaxng.org/ns/structure/1.0" 
                xmlns:snga="http://relaxng.org/ns/compatibility/annotations/1.0"
                xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
                xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:xalan="http://xml.apache.org/xalan" exclude-result-prefixes="sc sp sm sng snga xalan" version="1.0">
<xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>
	
<xsl:include href="bsco:sm/model/relaxNg.xsl"/>
	 
<xsl:template match="sm:dataFormPrim">
<xsl:value-of select="execute(setEntryBuffer('ns', string(sm:identification/@targetPrefix), string(sm:identification/@targetNamespace)))"/>
<xsl:value-of select="execute(setEntryBuffer('ns', 'sp', 'http://www.utc.fr/ics/scenari/v3/primitive'))"/>
<sng:define name="{sm:identification/@targetPrefix}_{sm:identification/@code}">
<sng:element name="{sm:identification/@targetPrefix}:{sm:identification/@code}" snga:title="{si(@info, concat(filterInlineLoc(@name), ' (',@info, ')'), filterInlineLoc(@name))}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:apply-templates select="sm:structure"/>
</sng:element>
</sng:define>
</xsl:template>
<xsl:template match="sm:structure">
<xsl:choose>
<xsl:when test="*">
<xsl:apply-templates/>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:field | sm:group | sm:setOf" name="occ">
<xsl:choose>
<xsl:when test="@occurence='one'">
<xsl:apply-templates select="." mode="inOcc"/>
</xsl:when>
<xsl:when test="@occurence='oneOrMore'">
<sng:oneOrMore>
<xsl:apply-templates select="." mode="inOcc"/>
</sng:oneOrMore>
</xsl:when>
<xsl:when test="@occurence='zeroOrOne'">
<sng:optional>
<xsl:apply-templates select="." mode="inOcc"/>
</sng:optional>
</xsl:when>
<xsl:when test="@occurence='zeroOrMore'">
<sng:zeroOrMore>
<xsl:apply-templates select="." mode="inOcc"/>
</sng:zeroOrMore>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="." mode="inOcc"/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:subData">
		
<xsl:variable name="vIsInternalizable" select="testExpr(sm:allowedDataModel, resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true', 'or')"/>
<xsl:if test="$vIsInternalizable">
<xsl:call-template name="occ"/>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:field[sm:refItem]">
		
<xsl:variable name="vIsExternalizable" select="testExpr(sm:refItem/sm:allowedModel, resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isStandAloneItem')) = 'true', 'or')"/>
<xsl:if test="$vIsExternalizable">
<xsl:call-template name="occ"/>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:field" mode="inOcc">
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:apply-templates/>
</sng:element>
</xsl:template>
<xsl:template match="sm:group" mode="inOcc">
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:apply-templates/>
</sng:element>
</xsl:template>
<xsl:template match="sm:setOf" mode="inOcc">
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<sng:oneOrMore>
<sng:choice>
<xsl:apply-templates/>
</sng:choice>
</sng:oneOrMore>
</sng:element>
</xsl:template>
<xsl:template match="sm:subData" mode="inOcc" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<sng:element name="sp:{@code}">
<sng:choice>
<xsl:apply-templates/>
</sng:choice>
</sng:element>
</xsl:template>
<xsl:template match="sm:allowedDataModel">
<xsl:if test="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:if>
</xsl:template>
	
	
<xsl:template match="sm:string">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</xsl:template>
<xsl:template match="sm:enum">
<sng:choice>
<xsl:for-each select="descendant::sm:option">
<sng:value type="string" snga:title="{filterInlineLoc(@name)}"><xsl:value-of select="@key"/></sng:value>
</xsl:for-each>
</sng:choice>
</xsl:template>
<xsl:template match="sm:number">
<sng:data type="{si(@allowedDecimals='Infinity' or number(@allowedDecimals)&gt;0, 'decimal', 'integer')}">
<xsl:if test="not(contains(@min, 'Infinity'))"><sng:param name="minInclusive"><xsl:value-of select="@min"/></sng:param></xsl:if>
<xsl:if test="not(contains(@max, 'Infinity'))"><sng:param name="maxInclusive"><xsl:value-of select="@max"/></sng:param></xsl:if>
<xsl:if test="not(contains(@allowedDecimals, 'Infinity')) and number(@allowedDecimals)&gt;0"><sng:param name="fractionDigits"><xsl:value-of select="@allowedDecimals"/></sng:param></xsl:if>
</sng:data>
</xsl:template>
<xsl:template match="sm:date">
<sng:data type="date"/>
</xsl:template>
<xsl:template match="sm:url">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</xsl:template>
<xsl:template match="sm:refItem">
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
<sng:empty/>
</xsl:template>
<xsl:template match="sm:otherType">
<xsl:choose>
<xsl:when test="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="*"/>
<xsl:template match="text()|@*"/>
</xsl:stylesheet>