<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:java="http://xml.apache.org/xslt/java" 
	version="1.0"
	exclude-result-prefixes="sm sc xalan java">
	
<xsl:output method="xml" indent="no" omit-xml-declaration="yes"/>
	
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
	
<xsl:variable name="vStructureModel" select="computeNodeAgent(computeNodeAgent('//agentModel', 'source'))/sm:structure"/>
	
<xsl:template match="sm:callSubModel" mode="in">
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(../..)!='link' and ( boolean(ancestor::sm:content))">xhtmlContent</xsl:when>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:otherwise>navigation</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vCodes" select="si(	@refCode, 
												@refCode, 
												si(	ancestor::sm:forSubData/@codes,
													ancestor::sm:forSubData/@codes,
													../@field
											))"/>
<xsl:for-each select="xalan:tokenize($vCodes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:subData[@code=current()]"/>
<xsl:if test="boolean($vDefModel)">
<xsl:for-each select="$vDefModel/sm:allowedDataModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:fieldValueOtherType" mode="in">
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)!='link' and ( boolean(ancestor::sm:content))">xhtmlContent</xsl:when>
<xsl:otherwise>navigation</xsl:otherwise>
</xsl:choose>
</xsl:variable>
		
<xsl:variable name="vAxis" select="@axis"/>
<xsl:choose>
<xsl:when test="ancestor::sm:forField">
<xsl:variable name="vFor" select="ancestor::sm:forField"/>
<xsl:for-each select="xalan:tokenize($vFor/@codes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:field[@code=current()]/sm:otherType"/>
<xsl:if test="boolean($vDefModel)">
<call model="{$vDefModel/@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:if>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="vDefModel" select="$vStructureModel//sm:field[@code=@field]/sm:otherType"/>
<xsl:if test="boolean($vDefModel)">
<call model="{$vDefModel/@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:if>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:callRefModel" mode="in">
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(../..)!='link' and ( boolean(ancestor::sm:content))">xhtmlContent</xsl:when>
<xsl:otherwise>navigation</xsl:otherwise>
</xsl:choose>
</xsl:variable>
		
<xsl:variable name="vAxis" select="@axis"/>
<xsl:choose>
<xsl:when test="ancestor::sm:forField">
<xsl:variable name="vFor" select="ancestor::sm:forField"/>
<xsl:for-each select="xalan:tokenize($vFor/@codes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:field[@code=current()]/sm:refItem"/>
<xsl:if test="boolean($vDefModel)">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:variable name="vDefModel" select="$vStructureModel//sm:field[@code=current()/../@field]/sm:refItem"/>
<xsl:if test="boolean($vDefModel)">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:otherwise>
</xsl:choose>
</xsl:template>	
	
	
<xsl:template match="sm:callModel" mode="in">
<xsl:apply-templates mode="in">
<xsl:with-param name="vView" select="si(local-name(..)!='link', 'xhtmlContent', 'navigation')"/>
</xsl:apply-templates>
</xsl:template>
<xsl:template match="sm:current" mode="in">
<xsl:param name="vView"/>
<call model="{/sm:*/sm:model/@sc:refUri}" axis="{@axis}" view="{$vView}"/>
</xsl:template>
<xsl:template match="sm:root" mode="in">
<xsl:param name="vView"/>
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="agentsLies(computeNodeAgent('//agentGenerator', 'listAgentRootAllowed'))">
<call model="{java:getSrcUri(srcFileAgent(.))}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:template>
<xsl:template match="sm:lookForAscendants" mode="in">
<xsl:param name="vView"/>
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:template>
<xsl:template match="sm:agentPath" mode="in">
<xsl:param name="vView"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{@axis}" view="{$vView}"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="text()|@*" mode="in"/>
</xsl:stylesheet>
