<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling"
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:java="http://xml.apache.org/xslt/java"
	exclude-result-prefixes="java sm sc" 
	version="1.0">
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
<xsl:param name="vArguments"/>
	
	
	
<xsl:template name="tGetWspConfig">
<xsl:for-each select="/sm:extDefinition/sm:freeConfig/sm:freeWspType">
<xsl:apply-templates/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:freeSpace">
<xsl:copy-of select="parseXml(concat('&lt;root&gt;', text(), '&lt;/root&gt;'))/root/*"/>
</xsl:template>
	
<xsl:template match="sm:freeSsOverlay[@sc:refUri]">
<xsl:variable name="vModel" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:variable name="vOwnerSs" select="si(resultatAgent('//isPublicClass', codeAgent($vModel))='true', agent(resultatAgent('@@/findOwnerClass', codeAgent($vModel))))"/>  
<xsl:if test="$vOwnerSs">
<ssOverlay ssUri="{resultatAgent($vOwnerSs/rootPathSs)}/{resultatAgent($vModel/codeModel)}.ss.xml">
<xsl:copy-of select="parseXml(concat('&lt;ssFragment&gt;', text(), '&lt;/ssFragment&gt;'))"/>
</ssOverlay>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:freeSsOverlay[not(@sc:refUri)]">
<xsl:variable name="vSsFragment" select="parseXml(concat('&lt;ssFragment&gt;', text(), '&lt;/ssFragment&gt;'))"/>
<xsl:for-each select="/*/sm:publicClasses//sm:class">
<xsl:variable name="vModel" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:variable name="vOwnerSs" select="agent(resultatAgent('@@/findOwnerClass', codeAgent($vModel)))"/>
<xsl:if test="$vOwnerSs">
<ssOverlay ssUri="{resultatAgent($vOwnerSs/rootPathSs)}/{resultatAgent($vModel/codeModel)}.ss.xml">
<xsl:copy-of select="$vSsFragment"/>
</ssOverlay>
</xsl:if>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:generator" mode="skin">
<xsl:variable name="vGen" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:variable name="vCodeGen" select="resultatAgent($vGen/codeGenerator)"/>
<xsl:variable name="vIsGenInThisDef" select="testExpr(listGenerators(), resultatAgent(codeGenerator)=$vCodeGen, 'or')"/>
<xsl:variable name="vAgtSkinPath" select="si($vIsGenInThisDef, $vGen/skinPath, $vGen/extSkinPath)"/>
<xsl:variable name="vGenContext" select="."/>
		
<xsl:for-each select="agentsLies($vGen/listAgentRootAllowed)">
			
<xsl:variable name="vOwnerSs" select="si(resultatAgent(isStandAloneItem)='true', agent(resultatAgent('@@/findOwnerClass', codeAgent(.))))"/>
<xsl:if test="$vOwnerSs">
<ssOverlay ssUri="{resultatAgent(agent('rootPathSs', $vOwnerSs))}/{resultatAgent(codeModel)}.ss.xml">
<ssFragment>
<module code="gen_{$vCodeGen}" type="eu.scenari.wsp.module.gen.ModuleGenLoader">
<xsl:for-each select="$vGenContext/sm:skin">
<skin sc:refUri="{si($vIsGenInThisDef, resultatAgent($vGen/rootPathGen), resultatAgent('@@/rootPathSs'))}{resultatAgent($vAgtSkinPath, @code)}" code="{@code}" title="{@name}" owner="{resultatAgent('@@/key')}"/>
</xsl:for-each>
</module>
</ssFragment>
</ssOverlay>
</xsl:if>
</xsl:for-each>
</xsl:template>
	
	
<xsl:template match="sm:class" mode="overlayGen">
<xsl:if test="descendant::sm:generator or descendant::sm:interactiveGenerator or descendant::sm:deployment">
<xsl:variable name="vModel" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:variable name="vOwnerSs" select="si(resultatAgent('//isPublicClass', codeAgent($vModel))='true', agent(resultatAgent('@@/findOwnerClass', codeAgent($vModel))))"/>
<xsl:if test="$vOwnerSs">
<ssOverlay ssUri="{resultatAgent($vOwnerSs/rootPathSs)}/{resultatAgent($vModel/codeModel)}.ss.xml">
<ssFragment>
<xsl:for-each select="descendant::sm:generator | descendant::sm:interactiveGenerator">
<xsl:variable name="vGen" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:variable name="vGenCd" select="resultatAgent($vGen/codeGenerator)"/>
<xsl:if test="setEntryBuffer('genModulesForClass', concat($vGenCd, '@', resultatAgent($vModel/codeModel)))">
<module code="gen_{$vGenCd}" type="eu.scenari.wsp.module.gen.ModuleGenLoader" title="{si(../@name, ../@name, resultatAgent($vGen/nameGenerator))}">
<xsl:if test="@shared='true'">
<xsl:attribute name="shared">true</xsl:attribute>
</xsl:if>
<context>
<agtBag alias="@" type="append">
<bs sc:refUri="{resultatAgent($vGen/bsRootPath)}"/>
</agtBag>
</context>
<generator classGen="{resultatAgent($vGen/classGenerator)}">
<publishFiles sc:refUri="{resultatAgent($vGen/publishFilesFolderPath)}"/>
<xsl:variable name="vSkinPath" select="resultatAgent($vGen/skinPath, '')"/>
<xsl:if test="$vSkinPath">
<skin sc:refUri="{resultatAgent($vGen/rootPathGen)}{$vSkinPath}" code="default" title="{resultatAgent($vGen/skinName)}" owner="{resultatAgent('/@@/uri')}"/>
</xsl:if>
</generator>
</module>
</xsl:if>
</xsl:for-each>
<xsl:for-each select="descendant::sm:deployment">
<xsl:variable name="vGenDep" select="agent(concat('@', getIdFromPath(@sc:refUri)))"/>
<xsl:if test="$vGenDep">
<xsl:variable name="vDeployCd" select="resultatAgent($vGenDep/codeGenerator)"/>
<xsl:if test="setEntryBuffer('genModulesForClass', concat($vDeployCd, '@', resultatAgent($vModel/codeModel)))">
<module code="gen_{$vDeployCd}" type="eu.scenari.wsp.module.gen.ModuleGenLoader" title="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/nameGenerator'))}">
<xsl:if test="@shared='true'">
<xsl:attribute name="shared">true</xsl:attribute>
</xsl:if>
<context>
<agtBag alias="@" type="append">
<bs sc:refUri="{resultatAgent($vGenDep/bsRootPath)}"/>
</agtBag>
</context>
<generator classGen="{resultatAgent($vGenDep/classGenerator)}">
<publishFiles sc:refUri="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/publishFilesFolderPath'))}"/>
<xsl:variable name="vSkinPath" select="resultatAgent($vGenDep/skinPath, '')"/>
<xsl:if test="$vSkinPath">
<skin sc:refUri="{resultatAgent($vGenDep/rootPathGen)}{$vSkinPath}" code="default" title="{resultatAgent($vGenDep/skinName)}" owner="{resultatAgent('/@@/uri')}"/>
</xsl:if>
</generator>
</module>
<xsl:value-of select="resultatAgent($vGenDep/ssModuleGenDeploy)" disable-output-escaping="yes"/>
</xsl:if>
</xsl:if>
</xsl:for-each>
</ssFragment>
</ssOverlay>
</xsl:if>
</xsl:if>

</xsl:template>
	
</xsl:stylesheet>