<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sng="http://relaxng.org/ns/structure/1.0"
		xmlns:snga="http://relaxng.org/ns/compatibility/annotations/1.0"
		xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling"
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
		xmlns:xalan="http://xml.apache.org/xalan"
		xmlns:sma="kelis.fr:scenari/modeling/assessment"
		exclude-result-prefixes="sc sp sm sng snga xalan sma"
		version="1.0">
	
	
<xsl:import href="bsco:sma/commonRelaxNg.rng.xsl"/>
<xsl:import href="bsco:sma/feedbackIntervals.rng.xsl"/>
	
<xsl:variable name="vItemUid" select="concat(/sma:assmntUnitEditPrim/sm:identification/@targetPrefix, '_', /sma:assmntUnitEditPrim/sm:identification/@code)"/>
	
<xsl:template match="sma:assmntUnitEditPrim">
<xsl:value-of select="execute(setEntryBuffer('ns', string(sm:identification/@targetPrefix), string(sm:identification/@targetNamespace)))"/>
<xsl:value-of select="execute(setEntryBuffer('ns', 'sp', 'http://www.utc.fr/ics/scenari/v3/primitive'))"/>
<sng:define name="{sm:identification/@targetPrefix}_{sm:identification/@code}">
<sng:element name="{sm:identification/@targetPrefix}:{sm:identification/@code}" snga:title="{si(@info, concat(filterInlineLoc(@name), ' (',@info, ')'), filterInlineLoc(@name))}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:apply-templates select="sm:structure"/>
</sng:element>
</sng:define>
<xsl:apply-templates mode="mDefine"/>
</xsl:template>
	
<xsl:template match="sm:structure">
<xsl:apply-templates select="sm:meta" mode="title"/>
<xsl:apply-templates select="*[name()!='sm:globalExplanationModel']"/>
<xsl:apply-templates select="sm:globalExplanationModel"/>
<xsl:if test="count(*)=0">
			
<sng:empty/>
</xsl:if>
</xsl:template>
	
	
<xsl:template match="sm:interaction">
<xsl:apply-templates/>
</xsl:template>
	
	
<xsl:template match="sm:gapInText">
<xsl:for-each select="sm:textModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:gapText</xsl:with-param>
</xsl:call-template>
</xsl:for-each>
<xsl:apply-templates select="sm:scoreBounds | sm:feedbackModel"/>
</xsl:template>
	
	
<xsl:template match="sm:singleField">
<xsl:choose>
<xsl:when test="count(sm:stringField | sm:numberField | sm:notAssessableField)=1">
<xsl:apply-templates select="sm:stringField | sm:numberField | sm:notAssessableField"/>
</xsl:when>
<xsl:otherwise>
<sng:choice>
<xsl:apply-templates select="sm:stringField | sm:numberField | sm:notAssessableField"/>
</sng:choice>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:stringField">
<xsl:variable name="vSFSolution">
<sng:element name="sc:SFSolution" snga:title="{filterInlineLoc(sm:solution/@name)}">
<xsl:choose>
<xsl:when test="sm:solution/sm:synomyms">
<sng:oneOrMore>
<sng:element name="sc:value" snga:title="{filterInlineLoc(@name)}, {filterInlineLoc(sm:synomyms/@name)}">
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:element>
</sng:oneOrMore>
</xsl:when>
<xsl:otherwise>
<sng:element name="sc:value" snga:title="{filterInlineLoc(@name)}">
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:element>
</xsl:otherwise>
</xsl:choose>
<xsl:apply-templates select="sm:solution/sm:score | sm:solution/sm:feedback"/>
</sng:element>
</xsl:variable>
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:choose>
<xsl:when test="sm:solution/@allowMultipleSolutions='yes'">
<sng:oneOrMore>
<xsl:copy-of select="$vSFSolution"/>
</sng:oneOrMore>
</xsl:when>
<xsl:otherwise>
<xsl:copy-of select="$vSFSolution"/>
</xsl:otherwise>
</xsl:choose>
<xsl:if test="sm:undefinedResponse">
<sng:element name="sc:undefinedResponse" snga:title="{filterInlineLoc(sm:undefinedResponse/@name)}">
<xsl:choose>
<xsl:when test="boolean(sm:undefinedResponse/*[name()!='sm:synomyms'])">
<xsl:apply-templates select="sm:undefinedResponse/*[name()!='sm:synomyms']"/>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</sng:element>
</xsl:if>
</sng:element>
</xsl:template>

<xsl:template match="sm:numberField">
<xsl:variable name="vNFSolution">
<sng:element name="sc:NFSolution" snga:title="{filterInlineLoc(sm:solution/@name)}">
<sng:element name="sc:value" snga:title="{filterInlineLoc(@name)}">
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:element>
<sng:oneOrMore>
<sng:element name="sc:condition">
<sng:attribute name="operation"><sng:data type="string"/></sng:attribute>
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:element>
</sng:oneOrMore>
<xsl:apply-templates select="sm:solution/sm:score | sm:solution/sm:feedback"/>
</sng:element>
</xsl:variable>
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:copy-of select="$vNFSolution"/>
<xsl:if test="sm:undefinedResponse">
<sng:element name="sc:undefinedResponse" snga:title="{filterInlineLoc(sm:undefinedResponse/@name)}">
<xsl:choose>
<xsl:when test="boolean(sm:undefinedResponse/*[name()!='sm:synomyms'])">
<xsl:apply-templates select="sm:undefinedResponse/*[name()!='sm:synomyms']"/>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</sng:element>
</xsl:if>
</sng:element>
</xsl:template>

<xsl:template match="sm:score">
<sng:element name="sc:score" snga:title="{filterInlineLoc(@name)}">
<sng:attribute name="value"><sng:data type="int"/></sng:attribute>
<sng:empty/>
</sng:element>
</xsl:template>
<xsl:template match="sm:feedback">
<xsl:choose>
<xsl:when test="@usage='none'"/>
<xsl:when test="@usage='optional'">
<sng:optional>
<xsl:for-each select="ancestor::*[name()='sm:singleField' or name()='sm:fieldList']/sm:feedbackModel">
<xsl:call-template name="tFeedBackField"/>
</xsl:for-each>
</sng:optional>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="ancestor::*[name()='sm:singleField' or name()='sm:fieldList']/sm:feedbackModel">
<xsl:call-template name="tFeedBackField"/>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template name="tFeedBackField">
<sng:element name="sc:feedback">
<xsl:if test="@name"><xsl:attribute name="snga:title"><xsl:value-of select="filterInlineLoc(@name)"/></xsl:attribute></xsl:if>
<xsl:choose>
<xsl:when test="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:notAssessableField">
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:for-each select="sm:solutionModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:NAFSolution</xsl:with-param>
</xsl:call-template>
</xsl:for-each>
</sng:element>
</xsl:template>
	
	
<xsl:template match="sm:structuredFields">
<sng:element name="sc:core" snga:title="{filterInlineLoc(@name)}">
<sng:ref name="{concat($vItemUid, '_', generate-id())}"/>
</sng:element>
</xsl:template>

<xsl:template match="sm:structuredFields" mode="mDefine">
<xsl:variable name="vCount" select="count(sm:division | sm:contentModel | .//sm:stringField | .//sm:notAssessableField)"/>
<sng:define name="{concat($vItemUid, '_', generate-id())}">
<xsl:choose>
<xsl:when test="$vCount &gt; 1">
<sng:oneOrMore>
<sng:choice>
<xsl:apply-templates/>
</sng:choice>
</sng:oneOrMore>
</xsl:when>
<xsl:when test="$vCount = 1">
<sng:oneOrMore>
<xsl:apply-templates/>
</sng:oneOrMore>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</sng:define>
</xsl:template>
<xsl:template match="sm:division">
<sng:element name="sc:division" snga:title="{filterInlineLoc(@name)}">
<sng:attribute name="title">
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:attribute>
<sng:ref name="{concat($vItemUid, '_', generate-id(ancestor::sm:structuredFields))}"/>
</sng:element>
</xsl:template>
<xsl:template match="sm:contentModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:content</xsl:with-param>
</xsl:call-template>
</xsl:template>
<xsl:template match="sm:fieldList">
<xsl:apply-templates select="sm:stringField | sm:notAssessableField"/>
</xsl:template>
	
</xsl:stylesheet>