<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sng="http://relaxng.org/ns/structure/1.0"
		xmlns:snga="http://relaxng.org/ns/compatibility/annotations/1.0"
		xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling"
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
		xmlns:xalan="http://xml.apache.org/xalan"
		xmlns:sma="kelis.fr:scenari/modeling/assessment"
		exclude-result-prefixes="sc sp sm sng snga xalan sma"
		version="1.0">
	
	
<xsl:import href="bsco:sma/commonRelaxNg.rng.xsl"/>
<xsl:import href="bsco:sma/feedbackIntervals.rng.xsl"/>
	
<xsl:template match="sma:assmntUnitMcqPrim">
<xsl:value-of select="execute(setEntryBuffer('ns', string(sm:identification/@targetPrefix), string(sm:identification/@targetNamespace)))"/>
<xsl:value-of select="execute(setEntryBuffer('ns', 'sp', 'http://www.utc.fr/ics/scenari/v3/primitive'))"/>
<sng:define name="{sm:identification/@targetPrefix}_{sm:identification/@code}">
<sng:element name="{sm:identification/@targetPrefix}:{sm:identification/@code}" snga:title="{si(@info, concat(filterInlineLoc(@name), ' (',@info, ')'), filterInlineLoc(@name))}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:apply-templates select="sm:structure"/>
</sng:element>
</sng:define>
</xsl:template>
	
<xsl:template match="sm:structure">
<xsl:apply-templates select="sm:meta" mode="title"/>
<xsl:apply-templates select="*[name()!='sm:globalExplanationModel' and name()!='sm:hintModel']"/>
<xsl:apply-templates select="sm:globalExplanationModel"/>
<xsl:apply-templates select="sm:hintModel"/>
<xsl:if test="count(*)=0">
			
<sng:empty/>
</xsl:if>
</xsl:template>
	
	
<xsl:template match="sm:choices">
<sng:element name="sc:choices" snga:title="{filterInlineLoc(@name)}">
<xsl:apply-templates/>
</sng:element>
</xsl:template>
<xsl:template match="sm:choice">
<sng:oneOrMore>
<sng:element name="sc:choice" snga:title="{filterInlineLoc(@name)}">
				
<xsl:for-each select="ancestor::sm:structure/sm:solution/sm:multipleUserResponse/sm:booleanScoring">
<sng:attribute name="solution">
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:attribute>
</xsl:for-each>
				
<xsl:for-each select="ancestor::sm:structure/sm:solution/sm:singleUserResponse/sm:numericScoring/sm:feedbackModel">
<sng:attribute name="score">
<sng:data type="int"/>
</sng:attribute>
</xsl:for-each>
				
<xsl:for-each select="ancestor::sm:structure/sm:solution/sm:multipleUserResponse/sm:summedNumericScoring">
<xsl:if test="sm:scoreIfSelected">
<sng:attribute name="scoreIfSelected">
<sng:data type="int"/>
</sng:attribute>
</xsl:if>
<xsl:if test="sm:scoreIfUnselected">
<sng:attribute name="scoreIfUnselected">
<sng:data type="int"/>
</sng:attribute>
</xsl:if>
</xsl:for-each>
<xsl:apply-templates select="*[name()!='sm:choiceExplanationModel']"/>
				
<xsl:for-each select="ancestor::sm:structure/sm:solution/sm:singleUserResponse/sm:numericScoring/sm:feedbackModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:feedback</xsl:with-param>
</xsl:call-template>
</xsl:for-each>
<xsl:apply-templates select="sm:choiceExplanationModel"/>
</sng:element>
</sng:oneOrMore>
</xsl:template>
<xsl:template match="sm:choiceLabelModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:choiceLabel</xsl:with-param>
</xsl:call-template>
</xsl:template>
<xsl:template match="sm:choiceExplanationModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:choiceExplanation</xsl:with-param>
</xsl:call-template>
</xsl:template>
	
	
<xsl:template match="sm:solution">
<xsl:apply-templates/>
</xsl:template>
<xsl:template match="sm:singleUserResponse | sm:multipleUserResponse">
<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="sm:numericScoring"/>
	
<xsl:template match="sm:booleanScoring">
<xsl:choose>
<xsl:when test="count(*)=0 and not(ancestor::sm:singleUserResponse)"/>
<xsl:when test="count(*[name()!='sm:pointsIfRight' and name()!='sm:pointsIfWrong'])=0">
<sng:element name="sc:solution" snga:title="{filterInlineLoc(../../@name)}">
<xsl:if test="ancestor::sm:singleUserResponse">
<sng:attribute name="choice">
<sng:data type="int"/>
</sng:attribute>
</xsl:if>
<xsl:apply-templates/>
<sng:empty/>
</sng:element>
</xsl:when>
<xsl:otherwise>
<sng:element name="sc:solution" snga:title="{filterInlineLoc(../../@name)}">
<xsl:if test="ancestor::sm:singleUserResponse">
<sng:attribute name="choice">
<sng:data type="int"/>
</sng:attribute>
</xsl:if>
<xsl:apply-templates/>
</sng:element>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:mappedNumericScoring">
<sng:element name="sc:solutions" snga:title="{filterInlineLoc(../../@name)}">
<sng:oneOrMore>
<sng:element name="sc:response" snga:title="{filterInlineLoc(sm:response/@name)}">
<sng:attribute name="score">
<sng:data type="int"/>
</sng:attribute>
<sng:oneOrMore>
<sng:element name="sc:choice">
<sng:attribute name="solution">
<sng:data type="string">
<sng:param name="minLength ">1</sng:param>
</sng:data>
</sng:attribute>
<sng:empty/>
</sng:element>
</sng:oneOrMore>
<xsl:for-each select="sm:feedbackModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:feedback</xsl:with-param>
</xsl:call-template>
</xsl:for-each>
</sng:element>
</sng:oneOrMore>
<sng:element name="sc:undefinedResponse" snga:title="{filterInlineLoc(sm:undefinedResponse/@name)}">
<xsl:if test="sm:undefinedResponse/sm:scoring">
<sng:attribute name="score">
<sng:data type="int"/>
</sng:attribute>
</xsl:if>
<xsl:choose>
<xsl:when test="sm:feedbackModel">
<xsl:for-each select="sm:feedbackModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:feedback</xsl:with-param>
</xsl:call-template>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</sng:element>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:summedNumericScoring">
<xsl:choose>
<xsl:when test="sm:feedbackModel/@usage='optional'">
<sng:optional>
<sng:element name="sc:solution" snga:title="{filterInlineLoc(../../@name)}">
<xsl:apply-templates/>
</sng:element>
</sng:optional>
</xsl:when>
<xsl:when test="sm:feedbackModel">
<sng:element name="sc:solution" snga:title="{filterInlineLoc(../../@name)}">
<xsl:apply-templates/>
</sng:element>
</xsl:when>
</xsl:choose>
</xsl:template>
		
<xsl:template match="sm:pointsIfRight">
<sng:attribute name="pointsIfRight" snga:title="{filterInlineLoc(@name)}"><sng:data type="int"/></sng:attribute>
</xsl:template>
<xsl:template match="sm:pointsIfWrong">
<sng:attribute name="pointsIfWrong" snga:title="{filterInlineLoc(@name)}"><sng:data type="int"/></sng:attribute>
</xsl:template>
	
<xsl:template match="sm:booleanScoring/sm:feedbackModel">
<xsl:if test="sm:ifRight">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:feedbackRight</xsl:with-param>
<xsl:with-param name="pDocName"><xsl:value-of select="sm:ifRight/@name"/></xsl:with-param>
</xsl:call-template>
</xsl:if>
<xsl:if test="sm:ifWrong">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:feedbackWrong</xsl:with-param>
<xsl:with-param name="pDocName"><xsl:value-of select="sm:ifWrong/@name"/></xsl:with-param>
</xsl:call-template>
</xsl:if>
</xsl:template>
		
</xsl:stylesheet>