<?xml version="1.0" encoding="UTF-8"?>


<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
	xmlns:sma="kelis.fr:scenari/modeling/assessment" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:java="http://xml.apache.org/xslt/java" 
	version="1.0"
	exclude-result-prefixes="sm sc xalan java">
	
<xsl:output method="xml" indent="no" omit-xml-declaration="yes"/>
	
<xsl:param name="vDialog"/>
<xsl:param name="vAgent"/>
	
<xsl:variable name="vStructureModel" select="computeNodeAgent(computeNodeAgent('//agentModel', 'source'))/sm:structure"/>

	
<xsl:template match="sm:callSubModel" mode="in">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:when test="ancestor::sm:itemBody">navigation</xsl:when>
<xsl:when test="ancestor::sm:masteryScore or ancestor::sm:maxTimeAllowed or ancestor::sm:timeLimitAction">xhtmlContent</xsl:when>
<xsl:otherwise>scormCam</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:choose>
<xsl:when test="ancestor::sm:for/@codes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize(ancestor::sm:for/@codes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:callModel" mode="in">
<xsl:apply-templates mode="in">
<xsl:with-param name="vView" select="si(parent::sm:itemBody, 'navigation', si(ancestor::sm:masteryScore or ancestor::sm:maxTimeAllowed or ancestor::sm:timeLimitAction, 'xhtmlContent', 'scormCam'))"/>
</xsl:apply-templates>
</xsl:template>
<xsl:template match="sm:callModel/sm:current" mode="in">
<xsl:param name="vView"/>
<call direction="current" model="{/*/sm:model/@sc:refUri}" axis="{@axis}" view="{$vView}"/>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:root" mode="in">
<xsl:param name="vView"/>
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="agentsLies(computeNodeAgent('//agentGenerator', 'listAgentRootAllowed'))">
<call model="{java:getSrcUri(srcFileAgent(.))}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:lookForAscendants" mode="in">
<xsl:param name="vView"/>
<xsl:variable name="vAxis" select="@axis"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callModel/sm:agentPath" mode="in">
<xsl:param name="vView"/>
<xsl:for-each select="sm:callableModel">
<call model="{@sc:refUri}" axis="{@axis}" view="{$vView}"/>
</xsl:for-each>
</xsl:template>
	
<xsl:template match="sm:callPartMeta" mode="in">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vFor" select="ancestor::sm:for/@codes"/>
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:when test="ancestor::sm:itemBody">navigation</xsl:when>
<xsl:when test="ancestor::sm:masteryScore or ancestor::sm:maxTimeAllowed or ancestor::sm:timeLimitAction">xhtmlContent</xsl:when>
<xsl:otherwise>scormCam</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<xsl:choose>
<xsl:when test="$vFor = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:meta|sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize($vFor, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:meta|$vDefModel/sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="{$vView}"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:callCompositionMeta" mode="in">
<xsl:variable name="vView">
<xsl:choose>
<xsl:when test="local-name(..)='fullTitleText' or local-name(..)='shortTitleText' ">title</xsl:when>
<xsl:when test="ancestor::sm:itemBody">navigation</xsl:when>
<xsl:otherwise>scormCam</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<call model="{$vStructureModel/sm:meta/@sc:refUri}" axis="{@axis}" view="{$vView}"/>
</xsl:template>
	
<xsl:template match="sm:compositionTitle" mode="in">
<call model="{/*/sm:model/@sc:refUri}" axis="{@axis}" view="title"/>
</xsl:template>
<xsl:template match="sm:partTitle" mode="in">
<xsl:variable name="vAxis" select="@axis"/>
<xsl:variable name="vFor" select="ancestor::sm:for/@codes"/>
<xsl:choose>
<xsl:when test="$vFor = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:meta|sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize($vFor, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:meta|$vDefModel/sm:metaIfExternalized">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template match="sm:subModelTitle" mode="in">		
<xsl:variable name="vAxis" select="@axis"/>
<xsl:choose>
<xsl:when test="ancestor::sm:for/@codes = '*'">
<xsl:for-each select="$vStructureModel//sm:part">
<xsl:for-each select="sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:for-each>
</xsl:when>
<xsl:otherwise>
<xsl:for-each select="xalan:tokenize(ancestor::sm:for/@codes, ' ')">
<xsl:variable name="vDefModel" select="$vStructureModel//sm:part[@code=current()]"/>
<xsl:if test="$vDefModel">
<xsl:for-each select="$vDefModel/sm:allowedModel">
<call model="{@sc:refUri}" axis="{$vAxis}" view="title"/>
</xsl:for-each>
</xsl:if>
</xsl:for-each>				
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="text()|@*" mode="in"/>
	
</xsl:stylesheet>
